bo4e.enum package
=================

Submodules
----------

bo4e.enum.anrede module
-----------------------

.. automodule:: bo4e.enum.anrede
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.arithmetische\_operation module
-----------------------------------------

.. automodule:: bo4e.enum.arithmetische_operation
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.bilanzierungsmethode module
-------------------------------------

.. automodule:: bo4e.enum.bilanzierungsmethode
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.botyp module
----------------------

.. automodule:: bo4e.enum.botyp
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.dienstleistungstyp module
-----------------------------------

.. automodule:: bo4e.enum.dienstleistungstyp
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.energierichtung module
--------------------------------

.. automodule:: bo4e.enum.energierichtung
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.gasqualitaet module
-----------------------------

.. automodule:: bo4e.enum.gasqualitaet
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.gebiettyp module
--------------------------

.. automodule:: bo4e.enum.gebiettyp
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.geraetetyp module
---------------------------

.. automodule:: bo4e.enum.geraetetyp
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.geschaeftspartnerrolle module
---------------------------------------

.. automodule:: bo4e.enum.geschaeftspartnerrolle
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.kontaktart module
---------------------------

.. automodule:: bo4e.enum.kontaktart
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.landescode module
---------------------------

.. automodule:: bo4e.enum.landescode
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.marktrolle module
---------------------------

.. automodule:: bo4e.enum.marktrolle
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.mengeneinheit module
------------------------------

.. automodule:: bo4e.enum.mengeneinheit
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.netzebene module
--------------------------

.. automodule:: bo4e.enum.netzebene
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.rollencodetyp module
------------------------------

.. automodule:: bo4e.enum.rollencodetyp
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.rufnummernart module
------------------------------

.. automodule:: bo4e.enum.rufnummernart
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.sparte module
-----------------------

.. automodule:: bo4e.enum.sparte
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.tarifart module
-------------------------

.. automodule:: bo4e.enum.tarifart
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.themengebiet module
-----------------------------

.. automodule:: bo4e.enum.themengebiet
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.titel module
----------------------

.. automodule:: bo4e.enum.titel
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.verbrauchsart module
------------------------------

.. automodule:: bo4e.enum.verbrauchsart
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.vertragsart module
----------------------------

.. automodule:: bo4e.enum.vertragsart
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.vertragsstatus module
-------------------------------

.. automodule:: bo4e.enum.vertragsstatus
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.zaehlerauspraegung module
-----------------------------------

.. automodule:: bo4e.enum.zaehlerauspraegung
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.zaehlertyp module
---------------------------

.. automodule:: bo4e.enum.zaehlertyp
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.zeiteinheit module
----------------------------

.. automodule:: bo4e.enum.zeiteinheit
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: bo4e.enum
   :members:
   :undoc-members:
   :show-inheritance:
